==> open-xchange-documents-ui_7.8.0.orig.tar.bz2: open-xchange-documents-ui-7.8.0/ui/apps/io.ox/office/portal/view/templateview.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH
 *
 * @author Edy Haryono <edy.haryono@open-xchange.com>
 */

define('io.ox/office/portal/view/templateview', [
    'io.ox/office/portal/portalutils',
    'io.ox/core/extensions',
    'io.ox/office/portal/action/templateactions'
], function (PortalUtils, Ext, TemplateActions) {

    'use strict';

    var templateView = Backbone.View.extend({

        tagName: 'div',

        className: 'office-portal-template',

        /**
         * Renders templates section of supported applications and 'My Templates' section
         *
         * @param {String} appBaseName
         *  The base name of the current application.
         *
         * @returns {templateView}
         */
        render: function (appBaseName) {

            // render nothing if we are on Text app on Android with non-supported Chrome or other browser
            if ((_.browser.Android) && (appBaseName === 'text') && !PortalUtils.CHROME_ON_ANDROID) { return; }

            var self = this,
                templateTypeWrapper = $('<div>').addClass('template-type-wrapper col-xs-12'),
                templateWrapper = $('<div>').addClass('template-list f6-target');

            templateTypeWrapper.append(templateWrapper);

            self.$el.append(templateTypeWrapper);

            // draw create with blank template
            TemplateActions[appBaseName].invoke('draw', templateWrapper, Ext.Baton({ app: self.model }));

            // get right templates to render from template collection
            var userTemplates = this.collection.getTemplates(appBaseName, 'user'),
                globalTemplates = this.collection.getTemplates(appBaseName, 'global');

            // render user templates for current active app type
            _.each(userTemplates, function (template) {
                TemplateActions[appBaseName + 'user'].invoke('draw', templateWrapper, Ext.Baton({ data: template.attributes }));
            });

            // render global templates for active app type
            _.each(globalTemplates, function (template) {
                TemplateActions[appBaseName + 'global'].invoke('draw', templateWrapper, Ext.Baton({ data: template.attributes }));
            });

            return this;
        }

    });

    return templateView;

});

==> open-xchange-documents-ui_7.8.1.orig.tar.bz2: open-xchange-documents-ui-7.8.1/ui/apps/io.ox/office/portal/view/templateview.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Edy Haryono <edy.haryono@open-xchange.com>
 */

define('io.ox/office/portal/view/templateview', [
    'io.ox/office/portal/portalutils',
    'io.ox/core/extensions',
    'io.ox/office/portal/action/templateactions'
], function (PortalUtils, Ext, TemplateActions) {

    'use strict';

    var templateView = Backbone.View.extend({

        tagName: 'div',

        className: 'office-portal-template',

        /**
         * Renders templates section of supported applications and 'My Templates' section
         *
         * @param {String} appBaseName
         *  The base name of the current application.
         *
         * @returns {templateView}
         */
        render: function (appBaseName) {

            // render nothing if we are on Text app on Android with non-supported Chrome or other browser
            if ((_.browser.Android) && (appBaseName === 'text') && !PortalUtils.CHROME_ON_ANDROID) { return; }

            var self = this,
                templateTypeWrapper = $('<div>').addClass('template-type-wrapper col-xs-12'),
                templateWrapper = $('<div>').addClass('template-list f6-target');

            templateTypeWrapper.append(templateWrapper);

            self.$el.append(templateTypeWrapper);

            // draw create with blank template
            TemplateActions[appBaseName].invoke('draw', templateWrapper, Ext.Baton({ app: self.model, appBaseName: appBaseName }));

            // get templates to render from template collection for all sources (user, admin, global)
            // and render the templates for the active app type
            _.each(['user', 'admin', 'global'], function (templateSource) {

                // 'user' and 'admin' templates are used alike while rendering templates,
                // therefore is only differentiated between 'user' and 'global' here
                var type = ((templateSource === 'global') ? 'global' : 'user');

                _.each(this.collection.getTemplates(appBaseName, templateSource), function (template) {
                    // render
                    TemplateActions[appBaseName + type].invoke('draw', templateWrapper, Ext.Baton({ data: template.attributes }));
                });
            }, this);

            return this;
        }

    });

    return templateView;

});
